;; CADVault sample
;;
;; Create a default shallow vault in each layout of the current drawing
;;
;; usage:
;; (lockAll "MyVaultName")
;;

(defun lockAll (VaultName / *ThisApp* *ThisDrawing* ProgId VC lockLayout isLockable hasEntities)
  (vl-load-com)
  (command "_CADVAULTSTART") ;ensure CADVault Runtime modules are loaded
  (setq *ThisApp* (vlax-get-acad-object)
    *ThisDrawing* (vla-get-activedocument *ThisApp*)
    ProgId (strcat "CADVault." (substr (getvar "ACADVER") 1 2) ".VaultCreator")
    VC (vla-GetInterfaceObject (vlax-get-acad-object) ProgId))

  (defun hasEntities (SpaceBTR / idx maxidx)
    (setq idx -1 maxidx (vla-get-Count SpaceBTR) found nil)
    (while
      (and
        (< (setq idx (1+ idx)) maxidx)
	(eq (vla-get-ObjectName (vla-Item SpaceBTR idx)) "AcDbViewport")))
    (< idx maxidx))

  (defun isLockable (SpaceBTR)
    (and (> (vla-get-Count SpaceBTR) 0)
      (= (vla-get-IsXref SpaceBTR) :vlax-false)
      (hasEntities SpaceBTR)))

  (defun lockLayout (Layout VC)
    (vlax-invoke-method VC 'CreateShallowVault
      (strcat VaultName " [" (vla-get-Name Layout) "]") ;vault name
      (vla-get-Block Layout) ;containing block table record
      (vlax-3d-point '(0 0 0)) ;insertion point is 0,0,0
      :vlax-false)) ;print status messages (:vlax-true for silent mode)

  ;iterate through each layout and create a shallow vault of all entities in the layout
  (vlax-for Layout (vla-get-Layouts *ThisDrawing*)
    (if (isLockable (vla-get-Block Layout))
      (if (not (lockLayout Layout VC))
        (alert (strcat "\nVault creation failed for layout " (vla-get-Name Layout) "!")))))
  (princ)
)
